@@ -2,12 +2,17 @@ package Plack::App::CGIBin;
 use strict;
 use warnings;
 use parent qw/Plack::App::File/;
-use Plack::App::WrapCGI;
+use CGI::Emulate::PSGI;
+use CGI::Compile;
 
 sub serve_path {
     my($self, $env, $file) = @_;
 
-    my $app = $self->{_compiled}->{$file} ||= Plack::App::WrapCGI->new(script => $file);
+    my $app = $self->{_compiled}->{$file} ||= do {
+        my $sub = CGI::Compile->compile($file);
+        my $app = CGI::Emulate::PSGI->handler($sub);
+    };
+
     $app->($env);
 }
 
@@ -35,7 +40,7 @@ Plack::App::CGIBin - cgi-bin replacement for Plack servers
 =head1 DESCRIPTION
 
 Plack::App::CGIBin allows you to load CGI scripts from a directory and
-convert them into a (persistent) PSGI application. This application
+convert them into a (persistent) PSGI applicaiton. This application
 uses L<CGI::Compile> to compile a cgi script into a sub (like
 L<ModPerl::Registry>) and then run it using L<CGI::Emulate::PSGI>.
 
@@ -46,16 +51,12 @@ This module does not (yet) stat files nor recompile files on every
 request for the interest of performance. You need to restart the
 server process to reflect the changes to the CGI scripts.
 
-See also L<Plack::App::WrapCGI> if you compile one CGI script into a
-PSGI application without serving CGI scripts from a directory, to
-remove overhead of filesystem lookups, etc.
-
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
 
 =head1 SEE ALSO
 
-L<Plack::App::File> L<CGI::Emulate::PSGI> L<CGI::Compile> L<Plack::App::WrapCGI>
+L<Plack::App::File> L<CGI::Emulate::PSGI> L<CGI::Compile>
 
 =cut
