@@ -17,6 +17,8 @@ sub test_psgi {
         my $req = shift;
         my $env = $req->to_psgi;
         my $res = HTTP::Response->from_psgi($app->($env));
+        $res->request($req);
+        return $res;
     };
 
     $client->($cb);
